@@ -353,11 +353,6 @@ static void xpad_pad_constructed (GObject *object)
 
 	g_object_set (G_OBJECT (pad), "child", vbox, NULL);
 
-	xpad_pad_notify_has_scrollbar (pad);
-	xpad_pad_notify_has_selection (pad);
-	xpad_pad_notify_clipboard_owner_changed (pad);
-	xpad_pad_notify_undo_redo_changed (pad);
-
 	pad->priv->clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
 
 	xpad_pad_sync_title (pad);
@@ -1103,9 +1098,6 @@ xpad_pad_configure_event (XpadPad *pad, GdkEventConfigure *event)
 			xpad_pad_save_info_delayed(pad);
 		}
 	}
-	else {
-		g_warning("There is a problem in the program Xpad. In function 'xpad_pad_configure_event' the variable 'event->width' or 'event->height' is not a positive number. Please send a bugreport to https://bugs.launchpad.net/xpad/+filebug to help improve Xpad.");
-	}
 
 	/* If the location of the pad has changed, save it. */
 	if (pad->priv->x != event->x || pad->priv->y != event->y) {
@@ -1226,7 +1218,6 @@ xpad_pad_load_content (XpadPad *pad)
 	g_free (content);
 	xpad_text_buffer_thaw_undo (XPAD_TEXT_BUFFER (buffer));
 
-	xpad_pad_text_changed(pad, buffer);
 	pad->priv->unsaved_content = FALSE;
 }
 
